@@ -8,8 +8,6 @@
 import logging
 import json
 import matplotlib.pyplot as plt
-# mine
-import preprocessing
 
 
 class HandwrittenData(object):
